tlslite.messages.Finished

Package tlslite :: Module messages :: Class Finished |
[hide private]
[frames] | no frames]

# Class Finished

source code

    HandshakeMsg --+
                   |
                  Finished

Instance Methods | [hide private]
__init__(self, version) | source code
create(self, verify_data) | source code
parse(self, p) | source code
write(self) | source code
Inherited from `HandshakeMsg`: `postWrite`

Method Details | [hide private]

### __init__(self, version) (Constructor) | source code
Overrides: HandshakeMsg.__init__